/*
	$Id: clamav_config.h 483 2009-03-29 16:41:19Z crosser $

	$Log: clamav_config.h,v $
	Revision 1.1  2004/12/14 00:25:34  crosser
	make configuration: options, limits etc.
	
*/

/*
	WHAT IS IT:
		modularized contentfilter for Zmailer
	COPYRIGHT:
		(c) 2003-2009 Eugene G. Crosser <crosser@average.org>
	LICENSE:
		The same set as apply to Zmailer code
*/

#ifndef RTCONFIG_H
#define RTCONFIG_H

typedef struct _clamav_cfg {
	struct cl_engine *root;
	char *dbdir;
	char *finaldbdir;
	unsigned int dbopts;
	int scantext;
	int filescan;
	unsigned int clamopts;
#ifdef HAVE_CL_INIT
	struct cl_settings *settings;
#else
	struct cl_limits limits;
#endif
} clamav_cfg_t;

extern clamav_cfg_t *
clamav_config(char *fn);

#endif
